/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Author: MARTIN GUZI
email: martin.guzi@econ.muni.cz
Date: July 19, 2023

Description: Program matches minimum wages to workers in the Structure of Earnings Survey (SES) 2018 

Reference month in SES is October 2018 with following exceptions in these countries:
* CZ 'average month'
* DE April 2018 
* FR 'average month'
* HU May 2018 
* SE September 2018 
* NO September 2018 

Data used: 
1. SES microdata can be obtained from Eurostat
https://ec.europa.eu/eurostat/web/microdata/structure-of-earnings-survey

2. Minimum Wage is sourced from WageIndicator Minimum Wage Database (MWDB). 
Database has more than 20,000 minimum wages in 188 countries that are updated monthly. 
It has time series data from January 2014 on, though for India only from January 2019 on (WageIndicator, 2023). 
WageIndicator operates national websites about work and wages in almost 200 countries.

3. Exchange rate is obtained from public Eurostat database
https://ec.europa.eu/eurostat/databrowser/product/page/tec00033
*/

** DATA FOLDER
gl path "d:\temp\ses\"
cd "$path"


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** 1. Download exchange rate 
	ssc install eurostatuse
	local item = "tec00033"
	eurostatuse `item', clear noflags nolabel long
	keep if time==2018
	g country=substr(currency,1,2)
	rename tec eur
	keep eur country
	di "Exchange rate to EUR: " _c
	list
	saveold "$path\eur_exchangerate2018",replace


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** 2. Prepare MW data 

import excel "$path\mwdb_BARWAGE.xls", sheet("data") firstrow clear
rename * , lower

** value of minimum wage 
g mw2018=.
replace mw2018=mw_mo_lcu_201810 // October 2018
replace mw2018=mw_mo_lcu_201809 if country_iso=="NO"
replace mw2018=mw_mo_lcu_201809 if country_iso=="SE"
replace mw2018=mw_mo_lcu_201804 if country_iso=="DE"
replace mw2018=mw_mo_lcu_201805 if country_iso=="HU"
** Minimum wages do not change over years in FR and CZ
l mw_mo_lcu_2018* if country_iso=="FR"
l mw_mo_lcu_2018* if country_iso=="CZ" & mw_code==20300002000001

keep mw_code mw2018 
save "$path\minimumwage2018",replace
 


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** 3. SES data
use "$path\ses2018.dta",clear

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** MERGE WORKERS WITH PROPER MINIMUM WAGE
** MW_CODE is unique identifier in MINIMUM WAGE DATABASE
g double mw_code=.

replace mw_code=10000000000001 if country=="BG"
replace mw_code=19100000000001 if country=="HR"
replace mw_code=20800000000000 if country=="DK"
replace mw_code=23300001000001 if country=="EE"  
replace mw_code=24600000000000 if country=="FI"
replace mw_code=25000000000001 if country=="FR"
replace mw_code=27600000000001 if country=="DE"
replace mw_code=30000001000001 if country=="EL" // greece
replace mw_code=34800001000001 if country=="HU"
replace mw_code=37200001000001 if country=="IE"
replace mw_code=38000000000000 if country=="IT"
replace mw_code=4000010000008  if country=="AT"
replace mw_code=42800001000001 if country=="LV"
replace mw_code=44000000000001 if country=="LT"
replace mw_code=44200001000002 if country=="LU" 
replace mw_code=47000001000001 if country=="MT" 
replace mw_code=52800002000015 if country=="NL"  
replace mw_code=5600000000001  if country=="BE"
replace mw_code=61600000000001 if country=="PL"
replace mw_code=62000100000001 if country=="PT"
replace mw_code=64200000000001 if country=="RO"
replace mw_code=70300000000001 if country=="SK"
replace mw_code=70500000000001 if country=="SI"
replace mw_code=72400001000003 if country=="ES"
replace mw_code=75200000000000 if country=="SE"
replace mw_code=20300002000001 if country=="CZ" 


** SPECIFIC MW by Occupation Estonia
// MW for Basic and upper secondary school teachers
replace mw_code=23300001000002 if country=="EE" & b23==234 
replace mw_code=23300001000002 if country=="EE" & b23==233 
replace mw_code=23300001000002 if country=="EE" & b23==232 

** SPECIFIC MW by Age
replace mw_code=52800002000009 if country=="NL" & b22_class=="14-19"
replace mw_code=44200001000002 if country=="LU" & b22_class=="14-19"

/** SPECIFIC MW by Occupation Cyprus
Security guards - Starting Salary
Security guards - After 6 months of service with same employer
Cleaners - Starting Salary
Cleaners - After 6 months of service with same employer
*/
replace mw_code=19600001000002 if country=="CY" & b23==541
replace mw_code=19600001000004 if country=="CY" & b23==911

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** merge minimum wages (mwwage2018 variables)
merge m:1 mw_code using minimumwage2018, gen(_mer) 
drop if _mer==2
ta country if _mer==1

di "  Are there missing MW? "
replace mw2018=. if mw2018<0
count if mw2018==.


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** Convert wages to EUR currency
** merge EUR rates
merge  m:1 country using "$path\eur_exchangerate2018", gen(_eur)
drop if _eur==2
replace eur=7.4182 if country=="HR"
replace eur=1 if eur==. // EUR countries
g wagegrhr=round(b43/eur, 0.01)
g wagegr0=round(b42/eur*100, 0.01)
g wagegr1=round(b42/eur*100/b271, 0.01)
g mw2018eur=round(mw2018/eur,1)

label var wagegrhr "average gross hourly earnings (in EUR)"
label var wagegr0  "gross monthly earnings (in EUR)"
label var wagegr1  "gross monthly earnings of a full-timer's normal hours (in EUR)"
label var mw2018   "Minimum wage in national currency"
label var mw2018eur "Minimum wage in EUR"

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
** Save final dataset
drop _mer _eur eur  eur mw_code
compress
save "$path\ses_mw2018.dta",replace


